@@ -2,21 +2,21 @@ package IO::Compress::Xz ;
 
 use strict ;
 use warnings;
-# use bytes;
+use bytes;
 require Exporter ;
 
-use IO::Compress::Base 2.069 ;
-use IO::Compress::Base::Common  2.069 qw(createSelfTiedObject);
-use IO::Compress::Adapter::Xz 2.069 ;
-use Compress::Raw::Lzma  2.069 ;
+use IO::Compress::Base 2.204 ;
+use IO::Compress::Base::Common  2.204 qw(createSelfTiedObject);
+use IO::Compress::Adapter::Xz 2.204 ;
+use Compress::Raw::Lzma  2.204 ;
 
 
-use vars qw($VERSION @ISA @EXPORT_OK %EXPORT_TAGS $XzError);
+our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $XzError);
 
-$VERSION = '2.069';
+$VERSION = '2.204';
 $XzError = '';
 
-@ISA    = qw(Exporter IO::Compress::Base);
+@ISA    = qw(IO::Compress::Base Exporter);
 @EXPORT_OK = qw( $XzError xz ) ;
 %EXPORT_TAGS = %IO::Compress::Base::EXPORT_TAGS ;
 
@@ -42,7 +42,7 @@ sub xz
 }
 
 
-sub mkHeader 
+sub mkHeader
 {
     my $self = shift ;
     return '';
@@ -67,7 +67,7 @@ sub ckParams
     my $got = shift;
 
     # TODO - validate the parameters
-    
+
     return 1 ;
 }
 
@@ -77,7 +77,7 @@ sub mkComp
     my $self = shift ;
     my $got = shift ;
 
-    my ($obj, $errstr, $errno) 
+    my ($obj, $errstr, $errno)
         = IO::Compress::Adapter::Xz::mkCompObject($got->getValue('preset'),
                                                   $got->getValue('extreme'),
                                                   $got->getValue('check')
@@ -85,7 +85,7 @@ sub mkComp
 
     return $self->saveErrorString(undef, $errstr, $errno)
         if ! defined $obj;
-    
+
     return $obj;
 }
 
@@ -117,7 +117,7 @@ sub getFileInfo
     my $self = shift ;
     my $params = shift;
     my $file = shift ;
-    
+
 }
 
 1;
@@ -127,17 +127,15 @@ __END__
 =head1 NAME
 
 IO::Compress::Xz - Write xz files/buffers
- 
- 
 
 =head1 SYNOPSIS
 
     use IO::Compress::Xz qw(xz $XzError) ;
 
-    my $status = xz $input => $output [,OPTS] 
+    my $status = xz $input => $output [,OPTS]
         or die "xz failed: $XzError\n";
 
-    my $z = new IO::Compress::Xz $output [,OPTS]
+    my $z = IO::Compress::Xz->new( $output [,OPTS] )
         or die "xz failed: $XzError\n";
 
     $z->print($string);
@@ -154,7 +152,7 @@ IO::Compress::Xz - Write xz files/buffers
     $z->autoflush();
     $z->input_line_number();
     $z->newStream( [OPTS] );
-    
+
     $z->close() ;
 
     $XzError ;
@@ -169,28 +167,13 @@ IO::Compress::Xz - Write xz files/buffers
     binmode $z
     fileno $z
     close $z ;
-    
 
 =head1 DESCRIPTION
 
-B<WARNING -- This is a Beta release>. 
-
-=over 5
-
-=item * DO NOT use in production code.
-
-=item * The documentation is incomplete in places.
-
-=item * Parts of the interface defined here are tentative.
-
-=item * Please report any problems you find.
-
-=back
-
-This module provides a Perl interface that allows writing xz 
+This module provides a Perl interface that allows writing xz
 compressed data to files or buffer.
 
-For reading xz files/buffers, see the companion module 
+For reading xz files/buffers, see the companion module
 L<IO::Uncompress::UnXz|IO::Uncompress::UnXz>.
 
 =head1 Functional Interface
@@ -202,7 +185,7 @@ section.
 
     use IO::Compress::Xz qw(xz $XzError) ;
 
-    xz $input_filename_or_reference => $output_filename_or_reference [,OPTS] 
+    xz $input_filename_or_reference => $output_filename_or_reference [,OPTS]
         or die "xz failed: $XzError\n";
 
 The functional interface needs Perl5.005 or better.
@@ -210,12 +193,13 @@ The functional interface needs Perl5.005 or better.
 =head2 xz $input_filename_or_reference => $output_filename_or_reference [, OPTS]
 
 C<xz> expects at least two parameters,
-C<$input_filename_or_reference> and C<$output_filename_or_reference>.
+C<$input_filename_or_reference> and C<$output_filename_or_reference>
+and zero or more optional parameters (see L</Optional Parameters>)
 
 =head3 The C<$input_filename_or_reference> parameter
 
 The parameter, C<$input_filename_or_reference>, is used to define the
-source of the uncompressed data. 
+source of the uncompressed data.
 
 It can take one of the following forms:
 
@@ -223,7 +207,7 @@ It can take one of the following forms:
 
 =item A filename
 
-If the <$input_filename_or_reference> parameter is a simple scalar, it is
+If the C<$input_filename_or_reference> parameter is a simple scalar, it is
 assumed to be a filename. This file will be opened for reading and the
 input data will be read from it.
 
@@ -233,17 +217,17 @@ If the C<$input_filename_or_reference> parameter is a filehandle, the input
 data will be read from it.  The string '-' can be used as an alias for
 standard input.
 
-=item A scalar reference 
+=item A scalar reference
 
 If C<$input_filename_or_reference> is a scalar reference, the input data
 will be read from C<$$input_filename_or_reference>.
 
-=item An array reference 
+=item An array reference
 
 If C<$input_filename_or_reference> is an array reference, each element in
 the array must be a filename.
 
-The input data will be read from each file in turn. 
+The input data will be read from each file in turn.
 
 The complete array will be walked to ensure that it only
 contains valid filenames before any data is compressed.
@@ -251,8 +235,8 @@ contains valid filenames before any data is compressed.
 =item An Input FileGlob string
 
 If C<$input_filename_or_reference> is a string that is delimited by the
-characters "<" and ">" C<xz> will assume that it is an 
-I<input fileglob string>. The input is the list of files that match the 
+characters "<" and ">" C<xz> will assume that it is an
+I<input fileglob string>. The input is the list of files that match the
 fileglob.
 
 See L<File::GlobMapper|File::GlobMapper> for more details.
@@ -273,7 +257,7 @@ these forms.
 =item A filename
 
 If the C<$output_filename_or_reference> parameter is a simple scalar, it is
-assumed to be a filename.  This file will be opened for writing and the 
+assumed to be a filename.  This file will be opened for writing and the
 compressed data will be written to it.
 
 =item A filehandle
@@ -282,14 +266,14 @@ If the C<$output_filename_or_reference> parameter is a filehandle, the
 compressed data will be written to it.  The string '-' can be used as
 an alias for standard output.
 
-=item A scalar reference 
+=item A scalar reference
 
 If C<$output_filename_or_reference> is a scalar reference, the
 compressed data will be stored in C<$$output_filename_or_reference>.
 
 =item An Array Reference
 
-If C<$output_filename_or_reference> is an array reference, 
+If C<$output_filename_or_reference> is an array reference,
 the compressed data will be pushed onto the array.
 
 =item An Output FileGlob
@@ -319,15 +303,15 @@ in C<$output_filename_or_reference> as a concatenated series of compressed data
 
 =head2 Optional Parameters
 
-Unless specified below, the optional parameters for C<xz>,
-C<OPTS>, are the same as those used with the OO interface defined in the
-L</"Constructor Options"> section below.
+The optional parameters for the one-shot function C<xz>
+are (for the most part) identical to those used with the OO interface defined in the
+L</"Constructor Options"> section. The exceptions are listed below
 
 =over 5
 
 =item C<< AutoClose => 0|1 >>
 
-This option applies to any input or output data streams to 
+This option applies to any input or output data streams to
 C<xz> that are filehandles.
 
 If C<AutoClose> is specified, and the value is true, it will result in all
@@ -338,9 +322,7 @@ This parameter defaults to 0.
 
 =item C<< BinModeIn => 0|1 >>
 
-When reading from a file or filehandle, set C<binmode> before reading.
-
-Defaults to 0.
+This option is now a no-op. All files will be read in binmode.
 
 =item C<< Append => 0|1 >>
 
@@ -369,7 +351,7 @@ written to it.  Otherwise the file pointer will not be moved.
 
 =back
 
-When C<Append> is specified, and set to true, it will I<append> all compressed 
+When C<Append> is specified, and set to true, it will I<append> all compressed
 data to the output data stream.
 
 So when the output is a filehandle it will carry out a seek to the eof
@@ -391,6 +373,22 @@ Defaults to 0.
 
 =head2 Examples
 
+Here are a few example that show the capabilities of the module.
+
+=head3 Streaming
+
+This very simple command line example demonstrates the streaming capabilities of the module.
+The code reads data from STDIN, compresses it, and writes the compressed data to STDOUT.
+
+    $ echo hello world | perl -MIO::Compress::Xz=xz -e 'xz \*STDIN => \*STDOUT' >output.xz
+
+The special filename "-" can be used as a standin for both C<\*STDIN> and C<\*STDOUT>,
+so the above can be rewritten as
+
+    $ echo hello world | perl -MIO::Compress::Xz=xz -e 'xz "-" => "-"' >output.xz
+
+=head3 Compressing a file from the filesystem
+
 To read the contents of the file C<file1.txt> and write the compressed
 data to the file C<file1.txt.xz>.
 
@@ -402,6 +400,8 @@ data to the file C<file1.txt.xz>.
     xz $input => "$input.xz"
         or die "xz failed: $XzError\n";
 
+=head3 Reading from a Filehandle and writing to an in-memory buffer
+
 To read from an existing Perl filehandle, C<$input>, and write the
 compressed data to a buffer, C<$buffer>.
 
@@ -410,12 +410,14 @@ compressed data to a buffer, C<$buffer>.
     use IO::Compress::Xz qw(xz $XzError) ;
     use IO::File ;
 
-    my $input = new IO::File "<file1.txt"
+    my $input = IO::File->new( "<file1.txt" )
         or die "Cannot open 'file1.txt': $!\n" ;
     my $buffer ;
-    xz $input => \$buffer 
+    xz $input => \$buffer
         or die "xz failed: $XzError\n";
 
+=head3 Compressing multiple files
+
 To compress all files in the directory "/my/home" that match "*.txt"
 and store the compressed data in the same directory
 
@@ -435,7 +437,7 @@ and if you want to compress each file one at a time, this will do the trick
     for my $input ( glob "/my/home/*.txt" )
     {
         my $output = "$input.xz" ;
-        xz $input => $output 
+        xz $input => $output
             or die "Error compressing '$input': $XzError\n";
     }
 
@@ -445,17 +447,17 @@ and if you want to compress each file one at a time, this will do the trick
 
 The format of the constructor for C<IO::Compress::Xz> is shown below
 
-    my $z = new IO::Compress::Xz $output [,OPTS]
+    my $z = IO::Compress::Xz->new( $output [,OPTS] )
         or die "IO::Compress::Xz failed: $XzError\n";
 
-It returns an C<IO::Compress::Xz> object on success and undef on failure. 
+It returns an C<IO::Compress::Xz> object on success and undef on failure.
 The variable C<$XzError> will contain an error message on failure.
 
-If you are running Perl 5.005 or better the object, C<$z>, returned from 
-IO::Compress::Xz can be used exactly like an L<IO::File|IO::File> filehandle. 
-This means that all normal output file operations can be carried out 
-with C<$z>. 
-For example, to write to a compressed file/buffer you can use either of 
+If you are running Perl 5.005 or better the object, C<$z>, returned from
+IO::Compress::Xz can be used exactly like an L<IO::File|IO::File> filehandle.
+This means that all normal output file operations can be carried out
+with C<$z>.
+For example, to write to a compressed file/buffer you can use either of
 these forms
 
     $z->print("hello world\n");
@@ -478,7 +480,7 @@ If the C<$output> parameter is a filehandle, the compressed data will be
 written to it.
 The string '-' can be used as an alias for standard output.
 
-=item A scalar reference 
+=item A scalar reference
 
 If C<$output> is a scalar reference, the compressed data will be stored
 in C<$$output>.
@@ -490,7 +492,7 @@ return undef.
 
 =head2 Constructor Options
 
-C<OPTS> is any combination of the following options:
+C<OPTS> is any combination of zero or more the following options:
 
 =over 5
 
@@ -505,7 +507,7 @@ This parameter defaults to 0.
 
 =item C<< Append => 0|1 >>
 
-Opens C<$output> in append mode. 
+Opens C<$output> in append mode.
 
 The behaviour of this option is dependent on the type of C<$output>.
 
@@ -571,7 +573,7 @@ This is a placeholder option.
 
 TODO
 
-=head1 Methods 
+=head1 Methods
 
 =head2 print
 
@@ -679,7 +681,7 @@ This is a noop provided for completeness.
 
     $z->opened()
 
-Returns true if the object currently refers to a opened file/buffer. 
+Returns true if the object currently refers to a opened file/buffer.
 
 =head2 autoflush
 
@@ -702,7 +704,7 @@ retrieve the autoflush setting.
     $z->input_line_number()
     $z->input_line_number(EXPR)
 
-This method always returns C<undef> when compressing. 
+This method always returns C<undef> when compressing.
 
 =head2 fileno
 
@@ -721,7 +723,7 @@ C<undef>.
     $z->close() ;
     close $z ;
 
-Flushes any pending compressed data and then closes the output file/buffer. 
+Flushes any pending compressed data and then closes the output file/buffer.
 
 For most versions of Perl this method will be automatically invoked if
 the IO::Compress::Xz object is destroyed (either explicitly or by the
@@ -754,9 +756,9 @@ the C<$z> object.
 
 See the L</"Constructor Options"> section for more details.
 
-=head1 Importing 
+=head1 Importing
 
-No symbolic constants are required by this IO::Compress::Xz at present. 
+No symbolic constants are required by IO::Compress::Xz at present.
 
 =over 5
 
@@ -767,15 +769,19 @@ Same as doing this
 
     use IO::Compress::Xz qw(xz $XzError) ;
 
-    
-
 =back
 
 =head1 EXAMPLES
 
+=head1 SUPPORT
+
+General feedback/questions/bug reports should be sent to
+L<https://github.com/pmqs/IO-Compress-Lzma/issues> (preferred) or
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=IO-Compress-Lzma>.
+
 =head1 SEE ALSO
 
-L<Compress::Zlib>, L<IO::Compress::Gzip>, L<IO::Uncompress::Gunzip>, L<IO::Compress::Deflate>, L<IO::Uncompress::Inflate>, L<IO::Compress::RawDeflate>, L<IO::Uncompress::RawInflate>, L<IO::Compress::Bzip2>, L<IO::Uncompress::Bunzip2>, L<IO::Compress::Lzma>, L<IO::Uncompress::UnLzma>, L<IO::Uncompress::UnXz>, L<IO::Compress::Lzop>, L<IO::Uncompress::UnLzop>, L<IO::Compress::Lzf>, L<IO::Uncompress::UnLzf>, L<IO::Uncompress::AnyInflate>, L<IO::Uncompress::AnyUncompress>
+L<Compress::Zlib>, L<IO::Compress::Gzip>, L<IO::Uncompress::Gunzip>, L<IO::Compress::Deflate>, L<IO::Uncompress::Inflate>, L<IO::Compress::RawDeflate>, L<IO::Uncompress::RawInflate>, L<IO::Compress::Bzip2>, L<IO::Uncompress::Bunzip2>, L<IO::Compress::Lzma>, L<IO::Uncompress::UnLzma>, L<IO::Uncompress::UnXz>, L<IO::Compress::Lzip>, L<IO::Uncompress::UnLzip>, L<IO::Compress::Lzop>, L<IO::Uncompress::UnLzop>, L<IO::Compress::Lzf>, L<IO::Uncompress::UnLzf>, L<IO::Compress::Zstd>, L<IO::Uncompress::UnZstd>, L<IO::Uncompress::AnyInflate>, L<IO::Uncompress::AnyUncompress>
 
 L<IO::Compress::FAQ|IO::Compress::FAQ>
 
@@ -785,7 +791,7 @@ L<IO::Zlib|IO::Zlib>
 
 =head1 AUTHOR
 
-This module was written by Paul Marquess, F<pmqs@cpan.org>. 
+This module was written by Paul Marquess, C<pmqs@cpan.org>.
 
 =head1 MODIFICATION HISTORY
 
@@ -793,8 +799,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2015 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2023 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
-
